x.sbw <-
structure(list(N = structure(list(Sex = c("Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex"
), Year = c(1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 
1979L, 1979L, 1979L, 1979L, 1980L, 1980L, 1980L, 1980L, 1980L, 
1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1981L, 1981L, 1981L, 
1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1982L, 
1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 
1982L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 
1983L, 1983L, 1983L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 
1984L, 1984L, 1984L, 1984L, 1984L, 1985L, 1985L, 1985L, 1985L, 
1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1986L, 1986L, 
1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 
1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 1987L, 
1987L, 1987L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 
1988L, 1988L, 1988L, 1988L, 1989L, 1989L, 1989L, 1989L, 1989L, 
1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1990L, 1990L, 1990L, 
1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1991L, 
1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 
1991L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 
1992L, 1992L, 1992L, 1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 
1993L, 1993L, 1993L, 1993L, 1993L, 1994L, 1994L, 1994L, 1994L, 
1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1995L, 1995L, 
1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 
1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 
1996L, 1996L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 
1997L, 1997L, 1997L, 1997L, 1998L, 1998L, 1998L, 1998L, 1998L, 
1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1999L, 1999L, 1999L, 
1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 2000L, 
2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 
2000L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 
2001L, 2001L, 2001L, 2002L, 2002L, 2002L, 2002L, 2002L, 2002L, 
2002L, 2002L, 2002L, 2002L, 2002L, 2003L, 2003L, 2003L, 2003L, 
2003L, 2003L, 2003L, 2003L, 2003L, 2003L, 2003L), Age = c(1L, 
2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 
3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 
7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 
4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 
1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 
5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 
2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 
6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 
3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 
7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 
4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
8L, 9L, 10L, 11L), N = c(11388, 9186.59, 9322.11, 27378.3, 9400.87, 
6118.08, 7056.13, 10557.6, 3735.48, 4300.04, 173854, 165808, 
9322.44, 7440.03, 6738.17, 18108.2, 6217.8, 4046.54, 4666.98, 
6982.89, 2470.68, 117833, 179990, 135740, 7578.74, 5625.83, 4825.16, 
12967.2, 4452.53, 2897.7, 3341.99, 5000.41, 86148.8, 41363, 147356, 
110655, 5915.24, 4253.29, 3647.96, 9803.56, 3366.25, 2190.75, 
2526.65, 68911.6, 8369.18, 33862.8, 119987, 85250.1, 4374.16, 
3145.2, 2697.58, 7249.48, 2489.25, 1620.01, 52826.8, 56502.2, 
6851.46, 27521.2, 90430.7, 60699.1, 3114.46, 2239.42, 1920.71, 
5161.72, 1772.38, 38766.9, 47015.9, 46256.6, 5576.62, 21101.2, 
66324.3, 44518.3, 2284.23, 1642.45, 1408.7, 3785.75, 29732.6, 
45379.5, 38491.1, 37700.8, 4342.51, 15890.6, 49946.8, 33525.4, 
1720.18, 1236.88, 1060.85, 25241.7, 101929, 37148.6, 31187.3, 
27400.2, 2900.4, 10613.5, 33359.9, 22391.9, 1148.93, 826.126, 
17567.8, 44995.9, 83442.3, 30119.3, 22846.1, 18560, 1964.64, 
7189.25, 22597, 15167.6, 778.248, 12459.5, 122039, 36832.6, 67317.4, 
20750.2, 13841, 11244.3, 1190.25, 4355.5, 13690.1, 9189.08, 8019.92, 
8233.83, 99885.6, 29419.7, 40532, 9615.83, 6414.03, 5210.71, 
551.572, 2018.38, 6344.13, 7974.88, 64160.3, 6739.61, 80194.6, 
19028.5, 21754.1, 5160.95, 3442.5, 2796.66, 296.037, 1083.3, 
7685.27, 900649, 52513.7, 5384.67, 48474.4, 8891.55, 10165.1, 
2411.59, 1608.6, 1306.82, 138.332, 4097.38, 186203, 737206, 42166.9, 
3488.9, 26107.4, 4788.82, 5474.76, 1298.84, 866.364, 703.83, 
2281.3, 80228, 152425, 595803, 29707.1, 2202.84, 16483.8, 3023.58, 
3456.68, 820.066, 547.009, 1884.77, 29719.9, 65679.9, 124029, 
455349, 21667.9, 1606.72, 12023, 2205.36, 2521.25, 598.145, 1773.71, 
242767, 24331.5, 53588.1, 97738.2, 349878, 16649.1, 1234.56, 
9238.2, 1694.54, 1937.27, 1822.47, 156472, 198748, 19822.9, 41534.4, 
73021.5, 261398, 12438.7, 922.356, 6901.98, 1266.02, 2808.95, 
53870, 128098, 161730, 15158.3, 30323.7, 53312, 190844, 9081.35, 
673.4, 5039.05, 2975.09, 183414, 44099.7, 103884, 118813, 10319.7, 
20644.3, 36294.7, 129926, 6182.56, 458.449, 5456.01, 71792.6, 
150147, 35741.4, 75751.7, 79826.7, 6933.52, 13870.3, 24385.3, 
87293.3, 4153.88, 3973.76, 127945, 58773.3, 122032, 26945.8, 
53966.2, 56869.3, 4939.5, 9881.31, 17372.3, 62188.6, 5790.22, 
80898.8, 104736, 47516, 86331.6, 17143, 34333.4, 36180.4, 3142.53, 
6286.53, 11052.3, 43248.5, 132697, 66222.2, 84525.9, 32883.4, 
52743.5, 10473.3, 20975.7, 22104.1, 1919.9, 3840.71, 33174.7)), .Names = c("Sex", 
"Year", "Age", "N"), row.names = c(NA, -275L), class = "data.frame"), 
    B = structure(list(Year = 1979:2003, VB = c(131690, 102328, 
    78202.7, 81762.9, 98222.7, 103435, 93393.3, 82795, 74156.8, 
    66999.4, 61316.9, 48023.5, 49651.9, 41522.6, 40712, 106922, 
    169675, 188673, 174776, 161236, 151664, 141758, 134561, 125483, 
    108262), SB = c(144912, 112910, 86131, 89790.7, 106502, 112214, 
    102675, 91262.4, 81174.9, 73292.2, 67014.5, 51936.8, 54155.3, 
    44591.2, 44066.9, 115982, 180145, 206647, 192110, 177517, 
    165516, 155116, 147828, 136696, 118563), Y = c(25305, 12828, 
    5989, 7915, 12803, 10777, 7490, 15252, 12804, 17422, 26611, 
    16542, 21314, 14208, 9316, 11668, 10436, 16504, 18923, 27164, 
    27205, 18409, 29999, 31847, NA), R = c(165808, 179990, 41363, 
    8369.18, 56502.2, 47015.9, 45379.5, 101929, 44995.9, 122039, 
    8233.83, 64160.3, 900649, 186203, 80228, 29719.9, 242767, 
    156472, 53870, 183414, 71792.6, 127945, 80898.8, 132697, 
    NA)), .Names = c("Year", "VB", "SB", "Y", "R"), row.names = c(NA, 
    -25L), class = "data.frame"), Sel = structure(list(Series = c("Gear 1", 
    "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
    "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Survey 1", "Survey 1", 
    "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
    "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Maturity", 
    "Maturity", "Maturity", "Maturity", "Maturity", "Maturity", 
    "Maturity", "Maturity", "Maturity", "Maturity", "Maturity"
    ), Sex = c("Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex"), Age = c(1L, 2L, 
    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 
    6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
    9L, 10L, 11L), P = c(0.000722682, 0.0562608, 0.609665, 1, 
    0.999999, 0.999998, 0.999997, 0.999994, 0.999991, 0.999988, 
    0.999984, 0, 0, 0, 1, 1, 0.999999, 0.999997, 0.999995, 0.999992, 
    0.999989, 0.999985, 0, 0.0500001084745763, 0.600000739281345, 
    0.950000460358527, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", 
    "Sex", "Age", "P"), row.names = c(NA, -33L), class = "data.frame"), 
    Dev = structure(list(sigmaR = structure(c(1, 1), .Names = c("Initial", 
    "Annual")), Initial = structure(c(-0.615429, -0.400785, 0.876576, 
    0.00762806, -0.221926, 0.120723, 0.723673, -0.115298, 0.225449
    ), .Names = c("2", "3", "4", "5", "6", "7", "8", "9", "10"
    )), Annual = structure(c(-0.600611, 0.719962, 0.815184, -0.637111, 
    -2.23805, -0.339889, -0.526867, -0.556781, 0.260493, -0.548288, 
    0.45809, -2.22976, -0.149204, 2.48759, 0.93586, 0.0955285, 
    -0.987471, 1.09206, 0.647962, -0.415831, 0.812267, -0.122915, 
    0.457657, 0.00141056), .Names = c("1979", "1980", "1981", 
    "1982", "1983", "1984", "1985", "1986", "1987", "1988", "1989", 
    "1990", "1991", "1992", "1993", "1994", "1995", "1996", "1997", 
    "1998", "1999", "2000", "2001", "2002"))), .Names = c("sigmaR", 
    "Initial", "Annual")), Survey = structure(list(Series = c(1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L), Year = 1979:2003, Obs = c(NA, 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 24033, 
    28841, 130535, NA, NA, 167668, NA, 135612, NA, 152799, NA
    ), CV = c(NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, 0.21, 0.36, 0.3, NA, NA, 0.18, NA, 0.17, NA, 0.68, 
    NA), Fit = c(131132, 101753, 76179.8, 63659.7, 77767.5, 99650.3, 
    92735.1, 76805.8, 68144.5, 60860.9, 48915, 42275.8, 36504.8, 
    40120.1, 26655.2, 33008.6, 153798, 181734, 171010, 144240, 
    138038, 135669, 116150, 116800, 92971.4)), .Names = c("Series", 
    "Year", "Obs", "CV", "Fit"), row.names = c(NA, -25L), class = "data.frame"), 
    CAc = structure(list(Series = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
    1L, 1L, 1L, 1L, 1L, 1L), Year = c(1979L, 1979L, 1979L, 1979L, 
    1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1979L, 1980L, 1980L, 
    1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 1980L, 
    1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 1981L, 
    1981L, 1981L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 1982L, 
    1982L, 1982L, 1982L, 1982L, 1983L, 1983L, 1983L, 1983L, 1983L, 
    1983L, 1983L, 1983L, 1983L, 1983L, 1983L, 1984L, 1984L, 1984L, 
    1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1984L, 1985L, 
    1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 1985L, 
    1985L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 1986L, 
    1986L, 1986L, 1986L, 1988L, 1988L, 1988L, 1988L, 1988L, 1988L, 
    1988L, 1988L, 1988L, 1988L, 1988L, 1989L, 1989L, 1989L, 1989L, 
    1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1989L, 1990L, 1990L, 
    1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 1990L, 
    1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 1991L, 
    1991L, 1991L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 1992L, 
    1992L, 1992L, 1992L, 1992L, 1993L, 1993L, 1993L, 1993L, 1993L, 
    1993L, 1993L, 1993L, 1993L, 1993L, 1993L, 1994L, 1994L, 1994L, 
    1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1994L, 1995L, 
    1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 1995L, 
    1995L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 1996L, 
    1996L, 1996L, 1996L, 1997L, 1997L, 1997L, 1997L, 1997L, 1997L, 
    1997L, 1997L, 1997L, 1997L, 1997L, 1998L, 1998L, 1998L, 1998L, 
    1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1998L, 1999L, 1999L, 
    1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 1999L, 
    2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 2000L, 
    2000L, 2000L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 2001L, 
    2001L, 2001L, 2001L, 2001L, 2002L, 2002L, 2002L, 2002L, 2002L, 
    2002L, 2002L, 2002L, 2002L, 2002L, 2002L), SS = c(20, 20, 
    20, 20, 20, 20, 20, 20, 20, 20, 20, 10, 10, 10, 10, 10, 10, 
    10, 10, 10, 10, 10, 33, 33, 33, 33, 33, 33, 33, 33, 33, 33, 
    33, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 17, 17, 17, 
    17, 17, 17, 17, 17, 17, 17, 17, 13, 13, 13, 13, 13, 13, 13, 
    13, 13, 13, 13, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 
    28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 206, 206, 206, 
    206, 206, 206, 206, 206, 206, 206, 206, 133, 133, 133, 133, 
    133, 133, 133, 133, 133, 133, 133, 94, 94, 94, 94, 94, 94, 
    94, 94, 94, 94, 94, 52, 52, 52, 52, 52, 52, 52, 52, 52, 52, 
    52, 121, 121, 121, 121, 121, 121, 121, 121, 121, 121, 121, 
    55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 80, 80, 80, 80, 
    80, 80, 80, 80, 80, 80, 80, 76, 76, 76, 76, 76, 76, 76, 76, 
    76, 76, 76, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 96, 185, 
    185, 185, 185, 185, 185, 185, 185, 185, 185, 185, 255, 255, 
    255, 255, 255, 255, 255, 255, 255, 255, 255, 175, 175, 175, 
    175, 175, 175, 175, 175, 175, 175, 175, 168, 168, 168, 168, 
    168, 168, 168, 168, 168, 168, 168, 321, 321, 321, 321, 321, 
    321, 321, 321, 321, 321, 321, 185, 185, 185, 185, 185, 185, 
    185, 185, 185, 185, 185), Sex = c("Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
    "Unisex", "Unisex", "Unisex", "Unisex"), Age = c(1L, 2L, 
    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 
    6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
    9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 
    1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 
    4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 
    7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
    10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 
    2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 
    5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 
    8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 
    11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 
    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 
    6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
    9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 
    1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 
    4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 
    7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
    10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L), 
        Obs = c(0, 0.0087, 0.0218, 0.2116, 0.0676, 0.0159, 0.0094, 
        0.0722, 0.0088, 0.0211, 0.5629, 0, 0.0022, 0.0125, 0.0295, 
        0.0716, 0.0105, 0.0324, 0.0241, 0.038, 0.0047, 0.7745, 
        0, 0.1547, 0.0093, 0.021, 0.0182, 0.0579, 0.0254, 0.0119, 
        0.0445, 0.0413, 0.6158, 0, 0.1152, 0.4338, 0.0625, 0.0252, 
        0.0137, 0.066, 0.0102, 0.0084, 0.0204, 0.2446, 0, 0.0333, 
        0.3893, 0.2786, 0.0119, 0.0157, 0.0123, 0.042, 0.0096, 
        2e-04, 0.2071, 0, 0.0022, 0.056, 0.2683, 0.3146, 0.0395, 
        0.0281, 0.0239, 0.058, 0.0184, 0.191, 0, 0.0233, 0.0118, 
        0.135, 0.3021, 0.2437, 0.0148, 0.0082, 0.0148, 0.0315, 
        0.2148, 0, 0.032, 0.1145, 0.0528, 0.0632, 0.2336, 0.2284, 
        0.0301, 0.017, 0.0249, 0.2035, 0, 0.0846, 0.1692, 0.169, 
        0.1332, 0.0039, 0.0517, 0.1958, 0.0974, 0.0061, 0.0891, 
        0, 0.0044, 0.2359, 0.139, 0.1159, 0.1147, 0.009, 0.0508, 
        0.1471, 0.0985, 0.0847, 0, 0.0268, 0.1484, 0.4747, 0.0839, 
        0.0617, 0.0568, 0.0089, 0.0168, 0.0441, 0.0779, 0, 0.003, 
        0.6124, 0.14, 0.1274, 0.0342, 0.0227, 0.0111, 0.0049, 
        0.0086, 0.0357, 0, 0.0973, 0.0193, 0.504, 0.1519, 0.1496, 
        0.0167, 0.0184, 0.0131, 0.0023, 0.0274, 0, 0.033, 0.3778, 
        0.0435, 0.3041, 0.0765, 0.1062, 0.0151, 0.0126, 0.0075, 
        0.0237, 0, 0.0335, 0.8324, 0.0657, 0.0043, 0.0368, 0.0069, 
        0.0155, 0.0014, 7e-04, 0.0028, 0, 0.0045, 0.103, 0.7913, 
        0.0421, 0.0022, 0.0309, 0.0049, 0.0156, 0.0011, 0.0044, 
        0, 0.0044, 0.0694, 0.1921, 0.6913, 0.0137, 0.0031, 0.015, 
        0.0031, 0.0035, 0.0044, 0, 0.0302, 0.0327, 0.0961, 0.1488, 
        0.6316, 0.0211, 0.0117, 0.0129, 0.005, 0.0099, 0, 0.0165, 
        0.1434, 0.0555, 0.0729, 0.1524, 0.5193, 0.0108, 0.0133, 
        0.0075, 0.0084, 0, 0.0127, 0.142, 0.3067, 0.0112, 0.0556, 
        0.0753, 0.349, 0.0208, 0.0063, 0.0204, 0, 0.0337, 0.0641, 
        0.2438, 0.2762, 0.0373, 0.0419, 0.0652, 0.2136, 0.008, 
        0.0162, 0, 0.0236, 0.2502, 0.0796, 0.1479, 0.1828, 0.0075, 
        0.0349, 0.0849, 0.1626, 0.026, 0, 0.0234, 0.093, 0.2719, 
        0.0592, 0.1702, 0.1054, 0.0176, 0.0204, 0.0746, 0.1643
        ), Fit = c(3.31e-05, 0.00207897, 0.0228609, 0.110127, 
        0.0378143, 0.0246095, 0.0283827, 0.042467, 0.0150256, 
        0.0172964, 0.699304, 0.000695684, 0.00304506, 0.0263346, 
        0.0391203, 0.105132, 0.0360991, 0.0234932, 0.0270953, 
        0.0405407, 0.014344, 0.6841, 0.000945006, 0.0554818, 
        0.0335681, 0.0408719, 0.035055, 0.0942068, 0.0323477, 
        0.0210518, 0.0242795, 0.0363277, 0.625865, 0.00016946, 
        0.0469982, 0.382448, 0.0335336, 0.024112, 0.0206804, 
        0.0555765, 0.0190832, 0.0124193, 0.0143235, 0.390656, 
        2.58e-05, 0.00811685, 0.311664, 0.363207, 0.0186361, 
        0.0134001, 0.0114929, 0.0308861, 0.0106053, 0.00690193, 
        0.225064, 0.000184507, 0.00174176, 0.0758156, 0.408616, 
        0.274272, 0.0140728, 0.0101189, 0.00867877, 0.0233233, 
        0.0080085, 0.175168, 0.000192145, 0.0147169, 0.0192264, 
        0.119328, 0.375067, 0.251753, 0.0129174, 0.00928809, 
        0.00796619, 0.0214083, 0.168137, 0.000207369, 0.0136932, 
        0.145338, 0.0274586, 0.10048, 0.315824, 0.211987, 0.010877, 
        0.00782099, 0.00670789, 0.159606, 0.000260869, 0.0376612, 
        0.147312, 0.18328, 0.148895, 0.015761, 0.0576746, 0.18128, 
        0.121679, 0.00624331, 0.0999529, 0.000702855, 0.0165143, 
        0.327069, 0.165365, 0.110303, 0.0896091, 0.00948541, 
        0.0347101, 0.109099, 0.0732298, 0.0639122, 5.82e-05, 
        0.0549743, 0.175461, 0.396505, 0.0940672, 0.0627453, 
        0.0509737, 0.00539574, 0.0197447, 0.0620609, 0.0780133, 
        0.00041937, 0.00342946, 0.442202, 0.172103, 0.196755, 
        0.0466781, 0.0311356, 0.0252943, 0.00267748, 0.00979778, 
        0.0695082, 0.00775027, 0.0351797, 0.0390899, 0.577201, 
        0.105875, 0.121039, 0.0287155, 0.019154, 0.0155606, 0.00164714, 
        0.0487881, 0.00119796, 0.369238, 0.228862, 0.0310599, 
        0.232421, 0.0426324, 0.0487388, 0.0115628, 0.00771272, 
        0.00626576, 0.0203089, 0.000134836, 0.0199431, 0.844746, 
        0.0690862, 0.00512287, 0.0383344, 0.00703157, 0.00803874, 
        0.00190712, 0.0012721, 0.00438311, 3.72e-05, 0.00640331, 
        0.131033, 0.78906, 0.0375476, 0.00278423, 0.0208343, 
        0.00382158, 0.00436896, 0.0010365, 0.00307355, 0.000341059, 
        0.00266114, 0.0635116, 0.190002, 0.680157, 0.0323655, 
        0.00239996, 0.0179588, 0.00329414, 0.00376597, 0.0035428, 
        0.000266903, 0.0263924, 0.0285252, 0.0980344, 0.172354, 
        0.616982, 0.0293592, 0.00217704, 0.0162907, 0.00298816, 
        0.00662991, 9.42e-05, 0.0174395, 0.238598, 0.0366805, 
        0.0733781, 0.129006, 0.461807, 0.0219752, 0.0016295, 
        0.0121935, 0.00719907, 0.000336386, 0.0062965, 0.160731, 
        0.301524, 0.0261895, 0.0523911, 0.0921085, 0.329724, 
        0.01569, 0.00116344, 0.0138461, 0.000158918, 0.0258745, 
        0.0667437, 0.232028, 0.244509, 0.0212374, 0.0424846, 
        0.0746919, 0.267377, 0.0127232, 0.0121714, 0.000292838, 
        0.0104723, 0.235626, 0.085339, 0.170914, 0.180108, 0.0156437, 
        0.0312946, 0.0550188, 0.196953, 0.0183377, 0.000214439, 
        0.021613, 0.106254, 0.316654, 0.0628784, 0.125931, 0.132705, 
        0.0115264, 0.023058, 0.0405382, 0.158628)), .Names = c("Series", 
    "Year", "SS", "Sex", "Age", "Obs", "Fit"), row.names = c(NA, 
    -253L), class = "data.frame")), .Names = c("N", "B", "Sel", 
"Dev", "Survey", "CAc"), call = quote(importCol(res.file = "c:/~/scape/example/sbw.res", 
    Dev = TRUE, Survey = TRUE, CAc = TRUE)), scape.version = "2.0-0", info = "", class = "scape")
